;   MiniTab tablet dialog
;   Copyright (c) 1995 by Mike Johnston
;   Peterborough, Ontario
;   Canada
;
;   Copyright (C) 1991-1994 by Autodesk, Inc.
;      
;   Permission to use, copy, modify, and distribute this software 
;   for any purpose and without fee is hereby granted, provided 
;   that the above copyright notice appears in all copies and that 
;   both that copyright notice and this permission notice appear in 
;   all supporting documentation.
;      
;   THIS SOFTWARE IS PROVIDED "AS IS" WITHOUT EXPRESS OR IMPLIED
;   WARRANTY.  ALL IMPLIED WARRANTIES OF FITNESS FOR ANY PARTICULAR
;   PURPOSE AND OF MERCHANTABILITY ARE HEREBY DISCLAIMED.

(defun c:mt () (c:minitab))
;-------------------------------------------------------------------
(defun ai_abort (app msg)
   (defun *error* (s)
      (if old_error (setq *error* old_error))
      (princ)
   )
   (if msg
     (alert (strcat " Application error: "
                    app
                    " \n\n  "
                    msg
                    "  \n"
            )
     )
   )
   (exit)
)
;-------------------------------------------------------------------
; Check to see if AI_UTILS is loaded, If not, try to find it,
; and then try to load it.
;
; If it can't be found or it can't be loaded, then abort the
; loading of this file immediately, preserving the (autoload)
; stub function.

(cond
   (  (and ai_dcl (listp ai_dcl)))          ; it's already loaded.

   (  (not (findfile "ai_utils.lsp"))                     ; find it
      (ai_abort "MINITAB"
                (strcat "Can't locate file AI_UTILS.LSP."
                        "\n Check support directory.")))

   (  (eq "failed" (load "ai_utils" "failed"))            ; load it
      (ai_abort "MINITAB" "Can't load file AI_UTILS.LSP"))
)

(if (not (ai_acadapp))               ; defined in AI_UTILS.LSP
    (ai_abort "MINITAB" nil)         ; a Nil <msg> supresses
)                                    ; ai_abort's alert box dialog.
;-------------------------------------------------------------------
(defun c:minitab (/ 
                    tab_list file_name tab_new tab_open tab_do tab_edit 
                    tab_up rewrite tab_over tab_cell tab_extract tab_pick 
                    minitab_main tab_help dcl_id tab_loop what_next
                 )
;--------------------------------------------------------------------
  (defun tab_about ()
    (if (not (new_dialog "tab_about" dcl_id)) (exit))
    (action_tile "accept" "(done_dialog)")
    (start_dialog) 
  )
;---------------------------------------------------------------------
  (defun tab_new (/ tab_menu file x y count alpha)
    (if (setq tab_menu (getfiled "Select a Minitab Menu" "" "mnu" 3))
      (progn
        (setq file_name tab_menu)
        (setq file (open file_name "w"))
        (write-line "MiniTab, Copyright 1995 Mike Johnston" file)
        (write-line "" file)
        (setq count 1 alpha 65)
        (repeat 100
          (if (= count 11) (setq count 1 alpha (1+ alpha)))
          (write-line (strcat (chr alpha) "-" (itoa count) "") file)
          (setq count (1+ count))
        )
        (write-line "" file)
        (close file)
        (set_tile "error" (strcat "File " tab_menu " created."))
      )
    )
  )
;-------------------------------------------------------------------
  (defun tab_open (/ item tab_menu file x y)
    (if (setq tab_menu (getfiled "Select a Minitab Menu" "" "mnu" 10))
      (progn
        (setq file_name (findfile tab_menu))
        (setq file (open file_name "r"))
        (setq item (read-line file))
        (close file)
        (if (/= item "MiniTab, Copyright 1995 Mike Johnston")
          (set_tile "error" "Not a valid MiniTab menu")
          (progn
            (setq tab_name (substr tab_menu 1 (- (strlen tab_menu) 4)))
            (if (findfile (strcat tab_name ".sld"))
              (progn
                (setq x (dimx_tile "tablet") y (dimy_tile "tablet"))
                (start_image "tablet")
                (fill_image 0 0 x y -2)
                (end_image)
                (start_image "tablet")
                (slide_image 0 0 x y tab_name)
                (end_image)
                (set_tile "title" (strcat tab_name ".MNU - MiniTab"))
                (set_tile "error" "")
              )
              (progn
                (set_tile "error" (strcat "Slide " tab_name " not found"))
                (setq tab_name "MINITAB")
                (setq file_name (findfile (strcat tab_name ".mnu")))
                (set_tile "title" (strcat tab_name ".MNU - MiniTab"))
              )
            )
          )
        )
      )
    )
  )
;-------------------------------------------------------------------
  (defun tab_do ( / item chrct count output para)
    (setq item (nth 2 tab_list))
    (setq maxs (1+ (strlen item)) count 0 chrct 0 para 0 tab_loop nil)
    (if (= (substr item 1 1) "*") (setq tab_loop T))
    (while (<= count maxs) 
      (setq chrct (1+ chrct))
      (setq count (1+ count))
      (if (= "(" (substr item count 1)) (setq para (1+ para)))
      (if (= ")" (substr item count 1)) (setq para (1- para)))
      (if (and (or (= " " (substr item count 1)) (= count maxs)) (= para 0))
        (progn
          (setq output (substr item  (- count (1- chrct)) (1- chrct))
                chrct 0
          )
          (cond
            ((= output (chr 42)))
            ((= output (chr 92))  (command pause))
            ((= output ";")  (command ""))
            ((wcmatch output "!*") (command (eval (read (substr output 2)))))
            ((wcmatch output (strcat (chr 40) "*")) (eval (read output)))
            (t (command output))
          )
        )
      )
    )
  )
;-------------------------------------------------------------------
  (defun tab_edit (/ )
    (if tab_list
      (progn
        (if (not (new_dialog "tab_edit" dcl_id)) (exit))
        (set_tile "cell" (nth 0 tab_list))
        (if (nth 1 tab_list) 
          (set_tile "description" (nth 1 tab_list))
        )
        (if (nth 2 tab_list)
          (set_tile "command" (nth 2 tab_list))
        )
        (mode_tile "description" 2)
        (action_tile "description" "(mode_tile \"command\" 2)")
        (action_tile "accept" "(tab_up)")
        (action_tile "cancel" "(done_dialog)")
        (action_tile "help" "(acad_helpdlg \"minitab\" \"edit\")")
        (start_dialog) 
      ) 
      (set_tile "error" "Select from tablet ")
    )
  )
;-------------------------------------------------------------------
  (defun tab_up (  / command_line description temp newdata file 
                     item test data cell
                )
    (setq tab_list nil)
    (setq command_line (get_tile "command"))
    (setq description (get_tile "description"))
    (setq cell (get_tile "cell"))
    (done_dialog)
    (setq file (open file_name "r"))             ;and read it
    (setq temp (open "temp.dat" "w"))     ;Make a temporary file
    (close temp)                                       ;close it to remove any past use
    (setq temp (open "temp.dat" "a"))      ;ready to append info to temp file
    (setq newdata (strcat cell "" description "" command_line)) ;Modified line in database
    (setq item (read-line file))
    (setq test T)
    (while test  
      (if item
        (progn
          (if (= (substr item 1 (1+ (strlen cell))) (strcat cell "")) ;match field that was modified
            (progn
              (setq data newdata)
              (write-line data temp) ;write line to temp file
            )
            (progn
              (setq data item)
              (write-line data temp) ; copy the rest of the database
            )
          )
          (setq item (read-line file))
        )
        (progn 
          (setq test nil) 
          (close file) 
          (close temp)
          (rewrite) ;write all of the temp file back into the database file
        )
      )
    )
    (set_tile "error" (strcat "Cell number " cell " is now updated."))
  )
;-------------------------------------------------------------------
  (defun rewrite ( / test data temp item file)
    (setq file (open file_name "w"))
    (close file)
    (setq temp (open "temp.dat" "r"))
    (setq file (open file_name "a"))
    (setq item (read-line temp))
    (setq test T)
    (while test  
      (if item
        (progn
          (setq data item)
          (write-line data file)
          (setq item (read-line temp))
        )
        (progn 
          (setq test nil) 
          (close file) 
          (close temp)
        )
      )
    )
  )

;-------------------------------------------------------------------
  (defun tab_over (/)
    (if (and tab_list (nth 2 tab_list))
      (done_dialog 1)
      (set_tile "error" "Select a tablet item")
    )
  )
;-------------------------------------------------------------------
  (defun tab_cell ( cell / item data test dlist len file)
    (setq len (strlen cell))
    (setq file (open file_name "r"))
    (setq test T)
    (setq item (read-line file))
    (while test
      (if (= (substr item 1 len) cell)
        (progn
          (tab_extract item)
          (setq test nil)
        )
        (if item 
          (setq item (read-line file)) 
          (progn (setq test nil) (close file))
        )
      )
    )
  )
;-------------------------------------------------------------------
  (defun tab_extract ( item / count chrct item data description 
                              display cell command_line
                     )
    (setq data item tab_list nil)
    (setq maxs (strlen data) count 1 chrct 1)
    (while (< count maxs)
      (if (/= "" (substr data count 1))
        (setq chrct (1+ chrct))
        (progn
          (setq item (substr data (- count (1- chrct)) (1- chrct)))
          (if (/= item "")
            (setq tab_list (append tab_list (list item)))
          )
          (setq chrct 1)
        )
      )
      (setq count (1+ count))
    )
    (setq item (substr data (1+ (- count chrct))))
    (if (/= item "")
      (setq tab_list (append tab_list (list item)))
    )
    (if (nth 2 tab_list)
      (progn
        (setq cell (nth 0 tab_list))
        (setq description (nth 1 tab_list))
        (setq command_line (nth 2 tab_list))
        (setq display (strcat "Cell: " cell "   " description))
      )
      (progn
        (setq cell (nth 0 tab_list))
        (setq display (strcat "Cell: "  cell))
      )
    )
    (set_tile "error" display) 
    (close file)
  )
;-------------------------------------------------------------------
  (defun tab_pick (key value x y / xdiv ydiv)
    (setq xdiv (/ (dimx_tile key) 10))
    (setq ydiv (/ (dimy_tile key)  10))
    (cond
      ((and (< x xdiv) (< y ydiv)) (tab_cell "A-1"))
      ((and (> x xdiv) (< x (* xdiv 2)) (< y ydiv)) (tab_cell "A-2"))
      ((and (> x (* xdiv 2)) (< x (* xdiv 3)) (< y ydiv)) (tab_cell "A-3"))
      ((and (> x (* xdiv 3)) (< x (* xdiv 4)) (< y ydiv)) (tab_cell "A-4"))
      ((and (> x (* xdiv 4)) (< x (* xdiv 5)) (< y ydiv)) (tab_cell "A-5"))
      ((and (> x (* xdiv 5)) (< x (* xdiv 6)) (< y ydiv)) (tab_cell "A-6"))
      ((and (> x (* xdiv 6)) (< x (* xdiv 7)) (< y ydiv)) (tab_cell "A-7"))
      ((and (> x (* xdiv 7)) (< x (* xdiv 8)) (< y ydiv)) (tab_cell "A-8"))
      ((and (> x (* xdiv 8)) (< x (* xdiv 9)) (< y ydiv)) (tab_cell "A-9"))
      ((and (> x (* xdiv 9)) (< y ydiv)) (tab_cell "A-10")) 

      ((and (< x xdiv) (> y ydiv) (< y (* ydiv 2))) (tab_cell "B-1"))
      ((and (> x xdiv) (< x (* xdiv 2)) (> y ydiv)(< y (* ydiv 2))) (tab_cell "B-2"))
      ((and (> x (* xdiv 2)) (< x (* xdiv 3)) (> y ydiv)(< y (* ydiv 2))) (tab_cell "B-3"))
      ((and (> x (* xdiv 3)) (< x (* xdiv 4)) (> y ydiv)(< y (* ydiv 2))) (tab_cell "B-4"))
      ((and (> x (* xdiv 4)) (< x (* xdiv 5)) (> y ydiv)(< y (* ydiv 2))) (tab_cell "B-5"))
      ((and (> x (* xdiv 5)) (< x (* xdiv 6)) (> y ydiv)(< y (* ydiv 2))) (tab_cell "B-6"))
      ((and (> x (* xdiv 6)) (< x (* xdiv 7)) (> y ydiv)(< y (* ydiv 2))) (tab_cell "B-7"))
      ((and (> x (* xdiv 7)) (< x (* xdiv 8)) (> y ydiv)(< y (* ydiv 2))) (tab_cell "B-8"))
      ((and (> x (* xdiv 8)) (< x (* xdiv 9)) (> y ydiv)(< y (* ydiv 2))) (tab_cell "B-9"))
      ((and (> x (* xdiv 9)) (> y ydiv)(< y (* ydiv 2))) (tab_cell "B-10"))

      ((and (< x xdiv) (> y (* ydiv 2)) (< y (* ydiv 3))) (tab_cell "C-1"))
      ((and (> x xdiv) (< x (* xdiv 2)) (> y (* ydiv 2))(< y (* ydiv 3))) (tab_cell "C-2")) 
      ((and (> x (* xdiv 2)) (< x (* xdiv 3)) (> y (* ydiv 2))(< y (* ydiv 3))) (tab_cell "C-3"))
      ((and (> x (* xdiv 3)) (< x (* xdiv 4)) (> y (* ydiv 2))(< y (* ydiv 3))) (tab_cell "C-4"))
      ((and (> x (* xdiv 4)) (< x (* xdiv 5)) (> y (* ydiv 2))(< y (* ydiv 3))) (tab_cell "C-5"))
      ((and (> x (* xdiv 5)) (< x (* xdiv 6)) (> y (* ydiv 2))(< y (* ydiv 3))) (tab_cell "C-6"))
      ((and (> x (* xdiv 6)) (< x (* xdiv 7)) (> y (* ydiv 2))(< y (* ydiv 3))) (tab_cell "C-7"))
      ((and (> x (* xdiv 7)) (< x (* xdiv 8)) (> y (* ydiv 2))(< y (* ydiv 3))) (tab_cell "C-8"))
      ((and (> x (* xdiv 8)) (< x (* xdiv 9)) (> y (* ydiv 2))(< y (* ydiv 3))) (tab_cell "C-9"))
      ((and (> x (* xdiv 9)) (> y (* ydiv 2))(< y (* ydiv 3))) (tab_cell "C-10"))

      ((and (< x xdiv) (> y (* ydiv 3)) (< y (* ydiv 4))) (tab_cell "D-1")) 
      ((and (> x xdiv) (< x (* xdiv 2)) (> y (* ydiv 3))(< y (* ydiv 4))) (tab_cell "D-2"))
      ((and (> x (* xdiv 2)) (< x (* xdiv 3)) (> y (* ydiv 3))(< y (* ydiv 4))) (tab_cell "D-3")) 
      ((and (> x (* xdiv 3)) (< x (* xdiv 4)) (> y (* ydiv 3))(< y (* ydiv 4))) (tab_cell "D-4")) 
      ((and (> x (* xdiv 4)) (< x (* xdiv 5)) (> y (* ydiv 3))(< y (* ydiv 4))) (tab_cell "D-5")) 
      ((and (> x (* xdiv 5)) (< x (* xdiv 6)) (> y (* ydiv 3))(< y (* ydiv 4))) (tab_cell "D-6")) 
      ((and (> x (* xdiv 6)) (< x (* xdiv 7)) (> y (* ydiv 3))(< y (* ydiv 4))) (tab_cell "D-7")) 
      ((and (> x (* xdiv 7)) (< x (* xdiv 8)) (> y (* ydiv 3))(< y (* ydiv 4))) (tab_cell "D-8")) 
      ((and (> x (* xdiv 8)) (< x (* xdiv 9)) (> y (* ydiv 3))(< y (* ydiv 4))) (tab_cell "D-9")) 
      ((and (> x (* xdiv 9)) (> y (* ydiv 3))(< y (* ydiv 4))) (tab_cell "D-10"))

      ((and (< x xdiv) (> y (* ydiv 4)) (< y (* ydiv 5))) (tab_cell "E-1"))
      ((and (> x xdiv) (< x (* xdiv 2)) (> y (* ydiv 4))(< y (* ydiv 5))) (tab_cell "E-2"))
      ((and (> x (* xdiv 2)) (< x (* xdiv 3)) (> y (* ydiv 4))(< y (* ydiv 5))) (tab_cell "E-3"))
      ((and (> x (* xdiv 3)) (< x (* xdiv 4)) (> y (* ydiv 4))(< y (* ydiv 5))) (tab_cell "E-4"))
      ((and (> x (* xdiv 4)) (< x (* xdiv 5)) (> y (* ydiv 4))(< y (* ydiv 5))) (tab_cell "E-5"))
      ((and (> x (* xdiv 5)) (< x (* xdiv 6)) (> y (* ydiv 4))(< y (* ydiv 5))) (tab_cell "E-6"))
      ((and (> x (* xdiv 6)) (< x (* xdiv 7)) (> y (* ydiv 4))(< y (* ydiv 5))) (tab_cell "E-7"))
      ((and (> x (* xdiv 7)) (< x (* xdiv 8)) (> y (* ydiv 4))(< y (* ydiv 5))) (tab_cell "E-8"))
      ((and (> x (* xdiv 8)) (< x (* xdiv 9)) (> y (* ydiv 4))(< y (* ydiv 5))) (tab_cell "E-9"))
      ((and (> x (* xdiv 9)) (> y (* ydiv 4))(< y (* ydiv 5))) (tab_cell "E-10"))

      ((and (< x xdiv) (> y (* ydiv 5)) (< y (* ydiv 6))) (tab_cell "F-1"))
      ((and (> x xdiv) (< x (* xdiv 2)) (> y (* ydiv 5))(< y (* ydiv 6))) (tab_cell "F-2"))
      ((and (> x (* xdiv 2)) (< x (* xdiv 3)) (> y (* ydiv 5))(< y (* ydiv 6))) (tab_cell "F-3"))
      ((and (> x (* xdiv 3)) (< x (* xdiv 4)) (> y (* ydiv 5))(< y (* ydiv 6))) (tab_cell "F-4"))
      ((and (> x (* xdiv 4)) (< x (* xdiv 5)) (> y (* ydiv 5))(< y (* ydiv 6))) (tab_cell "F-5"))
      ((and (> x (* xdiv 5)) (< x (* xdiv 6)) (> y (* ydiv 5))(< y (* ydiv 6))) (tab_cell "F-6"))
      ((and (> x (* xdiv 6)) (< x (* xdiv 7)) (> y (* ydiv 5))(< y (* ydiv 6))) (tab_cell "F-7"))
      ((and (> x (* xdiv 7)) (< x (* xdiv 8)) (> y (* ydiv 5))(< y (* ydiv 6))) (tab_cell "F-8"))
      ((and (> x (* xdiv 8)) (< x (* xdiv 9)) (> y (* ydiv 5))(< y (* ydiv 6))) (tab_cell "F-9"))
      ((and (> x (* xdiv 9)) (> y (* ydiv 5))(< y (* ydiv 6))) (tab_cell "F-10"))

      ((and (< x xdiv) (> y (* ydiv 6)) (< y (* ydiv 7))) (tab_cell "G-1"))
      ((and (> x xdiv) (< x (* xdiv 2)) (> y (* ydiv 6))(< y (* ydiv 7))) (tab_cell "G-2"))
      ((and (> x (* xdiv 2)) (< x (* xdiv 3)) (> y (* ydiv 6))(< y (* ydiv 7))) (tab_cell "G-3"))
      ((and (> x (* xdiv 3)) (< x (* xdiv 4)) (> y (* ydiv 6))(< y (* ydiv 7))) (tab_cell "G-4"))
      ((and (> x (* xdiv 4)) (< x (* xdiv 5)) (> y (* ydiv 6))(< y (* ydiv 7))) (tab_cell "G-5"))
      ((and (> x (* xdiv 5)) (< x (* xdiv 6)) (> y (* ydiv 6))(< y (* ydiv 7))) (tab_cell "G-6"))
      ((and (> x (* xdiv 6)) (< x (* xdiv 7)) (> y (* ydiv 6))(< y (* ydiv 7))) (tab_cell "G-7"))
      ((and (> x (* xdiv 7)) (< x (* xdiv 8)) (> y (* ydiv 6))(< y (* ydiv 7))) (tab_cell "G-8"))
      ((and (> x (* xdiv 8)) (< x (* xdiv 9)) (> y (* ydiv 6))(< y (* ydiv 7))) (tab_cell "G-9"))
      ((and (> x (* xdiv 9)) (> y (* ydiv 6))(< y (* ydiv 7))) (tab_cell "G-10"))

      ((and (< x xdiv) (> y (* ydiv 7)) (< y (* ydiv 8))) (tab_cell "H-1"))
      ((and (> x xdiv) (< x (* xdiv 2)) (> y (* ydiv 7))(< y (* ydiv 8))) (tab_cell "H-2"))
      ((and (> x (* xdiv 2)) (< x (* xdiv 3)) (> y (* ydiv 7))(< y (* ydiv 8))) (tab_cell "H-3"))
      ((and (> x (* xdiv 3)) (< x (* xdiv 4)) (> y (* ydiv 7))(< y (* ydiv 8))) (tab_cell "H-4"))
      ((and (> x (* xdiv 4)) (< x (* xdiv 5)) (> y (* ydiv 7))(< y (* ydiv 8))) (tab_cell "H-5"))
      ((and (> x (* xdiv 5)) (< x (* xdiv 6)) (> y (* ydiv 7))(< y (* ydiv 8))) (tab_cell "H-6"))
      ((and (> x (* xdiv 6)) (< x (* xdiv 7)) (> y (* ydiv 7))(< y (* ydiv 8))) (tab_cell "H-7"))
      ((and (> x (* xdiv 7)) (< x (* xdiv 8)) (> y (* ydiv 7))(< y (* ydiv 8))) (tab_cell "H-8"))
      ((and (> x (* xdiv 8)) (< x (* xdiv 9)) (> y (* ydiv 7))(< y (* ydiv 8))) (tab_cell "H-9"))
      ((and (> x (* xdiv 9)) (> y (* ydiv 7))(< y (* ydiv 8))) (tab_cell "H-10"))

      ((and (< x xdiv) (> y (* ydiv 8)) (< y (* ydiv 9))) (tab_cell "I-1"))
      ((and (> x xdiv) (< x (* xdiv 2)) (> y (* ydiv 8))(< y (* ydiv 9))) (tab_cell "I-2"))
      ((and (> x (* xdiv 2)) (< x (* xdiv 3)) (> y (* ydiv 8))(< y (* ydiv 9))) (tab_cell "I-3"))
      ((and (> x (* xdiv 3)) (< x (* xdiv 4)) (> y (* ydiv 8))(< y (* ydiv 9))) (tab_cell "I-4"))
      ((and (> x (* xdiv 4)) (< x (* xdiv 5)) (> y (* ydiv 8))(< y (* ydiv 9))) (tab_cell "I-5"))
      ((and (> x (* xdiv 5)) (< x (* xdiv 6)) (> y (* ydiv 8))(< y (* ydiv 9))) (tab_cell "I-6"))
      ((and (> x (* xdiv 6)) (< x (* xdiv 7)) (> y (* ydiv 8))(< y (* ydiv 9))) (tab_cell "I-7"))
      ((and (> x (* xdiv 7)) (< x (* xdiv 8)) (> y (* ydiv 8))(< y (* ydiv 9))) (tab_cell "I-8"))
      ((and (> x (* xdiv 8)) (< x (* xdiv 9)) (> y (* ydiv 8))(< y (* ydiv 9))) (tab_cell "I-9"))
      ((and (> x (* xdiv 9)) (> y (* ydiv 8))(< y (* ydiv 9))) (tab_cell "I-10"))

      ((and (< x xdiv) (> y (* ydiv 9))) (tab_cell "J-1"))
      ((and (> x xdiv) (< x (* xdiv 2)) (> y (* ydiv 9))) (tab_cell "J-2" ))
      ((and (> x (* xdiv 2)) (< x (* xdiv 3)) (> y (* ydiv 9))) (tab_cell "J-3"))
      ((and (> x (* xdiv 3)) (< x (* xdiv 4)) (> y (* ydiv 9))) (tab_cell "J-4"))
      ((and (> x (* xdiv 4)) (< x (* xdiv 5)) (> y (* ydiv 9))) (tab_cell "J-5"))
      ((and (> x (* xdiv 5)) (< x (* xdiv 6)) (> y (* ydiv 9))) (tab_cell "J-6"))
      ((and (> x (* xdiv 6)) (< x (* xdiv 7)) (> y (* ydiv 9))) (tab_cell "J-7"))
      ((and (> x (* xdiv 7)) (< x (* xdiv 8)) (> y (* ydiv 9))) (tab_cell "J-8")) 
      ((and (> x (* xdiv 8)) (< x (* xdiv 9)) (> y (* ydiv 9))) (tab_cell "J-9"))
      ((and (> x (* xdiv 9)) (> y (* ydiv 9))) (tab_cell "J-10"))
      (t (set_tile "error" "Try again"))
    )
  )
;-------------------------------------------------------------------
  (defun minitab_main ( / x y)
    (if (null tab_name) (setq tab_name "MINITAB"))
    (setq tab_list nil tab_chk nil tab_help "introduction")
    (setq file_name (findfile (strcat tab_name ".mnu")))
    (if (not (new_dialog "minitab" dcl_id)) (exit))
    (setq x (dimx_tile "tablet") y (dimy_tile "tablet"))
    (start_image "tablet")
    (slide_image 0 0 x y tab_name)
    (end_image)
    (set_tile "title" (strcat tab_name ".MNU - MiniTab"))
    (action_tile "tablet" "(tab_pick $key $value $x $y)")
    (action_tile "accept" "(tab_over)")
    (action_tile "cancel" "(done_dialog)")
    (action_tile "edit"   "(tab_edit)")
    (action_tile "open"   "(tab_open)")
    (action_tile "new"   "(tab_new)")
    (action_tile "about" "(tab_about)")
    (action_tile "help" "(acad_helpdlg \"minitab\" tab_help)")
    (setq what_next (start_dialog))
    (if (= what_next 1)
      (progn
        (tab_do)
        (while tab_loop (tab_do))
      )
    )
  )
;-------------------------------------------------------------------
  ;; Set up error function.
  (setq 
        ;old_cmd (getvar "cmdecho")    ; save current setting of cmdecho
        old_error  *error*            ; save current error function
        *error* ai_error              ; new error function
  )
  (cond
     (  (not (ai_transd)))                       ; transparent OK
     (  (not (ai_acadapp)))                      ; ACADAPP.EXP xloaded?
     (  (not (setq dcl_id (ai_dcl "minitab"))))  ; is .DCL file loaded?
     (t (minitab_main))                          ; proceed!
  )
  (setq *error* old_error) 
  (princ)
)


